import sys
import typing
import bpy.types


def abspath(path,
            *,
            start: typing.Union[str, bytes] = None,
            library: 'bpy.types.Library' = None):
    ''' Returns the absolute path relative to the current blend file using the "//" prefix.

    :param start: Relative to this path, when not set the current filename is used.
    :type start: typing.Union[str, bytes]
    :param library: The library this path is from. This is only included for convenience, when the library is not None its path replaces *start*.
    :type library: 'bpy.types.Library'
    '''

    pass


def basename(path):
    ''' Equivalent to os.path.basename , but skips a "//" prefix. Use for Windows compatibility.

    '''

    pass


def clean_name(name, *, replace='_'):
    ''' Returns a name with characters replaced that may cause problems under various circumstances, such as writing to a file. All characters besides A-Z/a-z, 0-9 are replaced with "_" or the *replace* argument if defined.

    '''

    pass


def display_name(name, *, has_ext=True, title_case=True):
    ''' Creates a display string from name to be used menus and the user interface. Intended for use with filenames and module names.

    '''

    pass


def display_name_from_filepath(name):
    ''' Returns the path stripped of directory and extension, ensured to be utf8 compatible.

    '''

    pass


def display_name_to_filepath(name):
    ''' Performs the reverse of display_name using literal versions of characters which aren't supported in a filepath.

    '''

    pass


def ensure_ext(filepath, ext: str, *, case_sensitive: bool = False):
    ''' Return the path with the extension added if it is not already set.

    :param ext: The extension to check for, can be a compound extension. Should start with a dot, such as '.blend' or '.tar.gz'.
    :type ext: str
    :param case_sensitive: Check for matching case when comparing extensions.
    :type case_sensitive: bool
    '''

    pass


def is_subdir(path: typing.Union[str, bytes], directory):
    ''' Returns true if *path* in a subdirectory of *directory*. Both paths must be absolute.

    :param path: An absolute path.
    :type path: typing.Union[str, bytes]
    '''

    pass


def module_names(path: str, *, recursive: bool = False) -> list:
    ''' Return a list of modules which can be imported from *path*.

    :param path: a directory to scan.
    :type path: str
    :param recursive: Also return submodule names for packages.
    :type recursive: bool
    :rtype: list
    :return: a list of string pairs (module_name, module_file).
    '''

    pass


def native_pathsep(path):
    ''' Replace the path separator with the systems native os.sep .

    '''

    pass


def reduce_dirs(dirs: list) -> list:
    ''' Given a sequence of directories, remove duplicates and any directories nested in one of the other paths. (Useful for recursive path searching).

    :param dirs: Sequence of directory paths.
    :type dirs: list
    :rtype: list
    :return: A unique list of paths.
    '''

    pass


def relpath(path: typing.Union[str, bytes],
            *,
            start: typing.Union[str, bytes] = None):
    ''' Returns the path relative to the current blend file using the "//" prefix.

    :param path: An absolute path.
    :type path: typing.Union[str, bytes]
    :param start: Relative to this path, when not set the current filename is used.
    :type start: typing.Union[str, bytes]
    '''

    pass


def resolve_ncase(path):
    ''' Resolve a case insensitive path on a case sensitive system, returning a string with the path if found else return the original path.

    '''

    pass



import sys
import typing


def assign_action():
    ''' Set this pose Action as active Action on the active Object :file: addons/pose_library/operators.py\:213 <https://developer.blender.org/diffusion/BA/addons/pose_library/operators.py$213> _

    '''

    pass


def catalog_delete(catalog_id: str = ""):
    ''' Remove an asset catalog from the asset library (contained assets will not be affected and show up as unassigned)

    :param catalog_id: Catalog ID, ID of the catalog to delete
    :type catalog_id: str
    '''

    pass


def catalog_new(parent_path: str = ""):
    ''' Create a new catalog to put assets in

    :param parent_path: Parent Path, Optional path defining the location to put the new catalog under
    :type parent_path: str
    '''

    pass


def clear(set_fake_user: bool = False):
    ''' Delete all asset metadata and turn the selected asset data-blocks back into normal data-blocks

    :param set_fake_user: Set Fake User, Ensure the data-block is saved, even when it is no longer marked as asset
    :type set_fake_user: bool
    '''

    pass


def list_refresh():
    ''' Trigger a reread of the assets

    '''

    pass


def mark():
    ''' Enable easier reuse of selected data-blocks through the Asset Browser, with the help of customizable metadata (like previews, descriptions and tags)

    '''

    pass


def open_containing_blend_file():
    ''' Open the blend file that contains the active asset :file: startup/bl_operators/assets.py\:111 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/assets.py$111> _

    '''

    pass


def tag_add():
    ''' Add a new keyword tag to the active asset :file: startup/bl_operators/assets.py\:52 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/assets.py$52> _

    '''

    pass


def tag_remove():
    ''' Remove an existing keyword tag from the active asset :file: startup/bl_operators/assets.py\:75 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/assets.py$75> _

    '''

    pass



import sys
import typing


def activate(template_id, reload_scripts):
    ''' 

    '''

    pass


def import_from_id(template_id, ignore_not_found):
    ''' 

    '''

    pass


def import_from_path(path, ignore_not_found):
    ''' 

    '''

    pass


def reset(reload_scripts):
    ''' 

    '''

    pass
